==> eslint-plugin-jsx-a11y-0.2.1.tgz: package/lib/rules/redundant-alt.js <==
/**
 * @fileoverview Enforce img alt attribute does not have the word image, picture, or photo.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

var _isHiddenFromScreenReader = require('../util/isHiddenFromScreenReader');

var _isHiddenFromScreenReader2 = _interopRequireDefault(_isHiddenFromScreenReader);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var REDUNDANT_WORDS = ['image', 'photo', 'picture'];

var errorMessage = 'Redundant alt attribute. Screen-readers already announce `img` tags as an image. ' + 'You don\'t need to use the words `image`, `photo,` or `picture` in the alt prop.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var type = node.name.name;
      if (type !== 'img') {
        return;
      }

      var altProp = (0, _hasAttribute2.default)(node.attributes, 'alt');
      var isVisible = (0, _isHiddenFromScreenReader2.default)(node.attributes) === false;

      if (Boolean(altProp) && typeof altProp === 'string' && isVisible) {
        var hasRedundancy = REDUNDANT_WORDS.some(function (word) {
          return Boolean(altProp.match(new RegExp(word, 'gi')));
        });

        if (hasRedundancy === true) {
          context.report({
            node: node,
            message: errorMessage
          });
        }

        return;
      }
    }
  };
};

module.exports.schema = [{ type: 'object' }];

==> eslint-plugin-jsx-a11y-0.4.1.tgz: package/lib/rules/redundant-alt.js <==
/**
 * @fileoverview Enforce img alt attribute does not have the word image, picture, or photo.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

var _isHiddenFromScreenReader = require('../util/isHiddenFromScreenReader');

var _isHiddenFromScreenReader2 = _interopRequireDefault(_isHiddenFromScreenReader);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var REDUNDANT_WORDS = ['image', 'photo', 'picture'];

var errorMessage = 'Redundant alt attribute. Screen-readers already announce `img` tags as an image. ' + 'You don\'t need to use the words `image`, `photo,` or `picture` in the alt prop.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var type = node.name.name;
      if (type !== 'img') {
        return;
      }

      var altProp = (0, _hasAttribute2.default)(node.attributes, 'alt');
      var isVisible = (0, _isHiddenFromScreenReader2.default)(node.attributes) === false;

      if (Boolean(altProp) && typeof altProp === 'string' && isVisible) {
        var hasRedundancy = REDUNDANT_WORDS.some(function (word) {
          return Boolean(altProp.match(new RegExp('(?!{)' + word + '(?!})', 'gi')));
        });

        if (hasRedundancy === true) {
          context.report({
            node: node,
            message: errorMessage
          });
        }

        return;
      }
    }
  };
};

module.exports.schema = [{ type: 'object' }];
